<?php
session_start();

// Initialize the cart if it's not already
if (!isset($_SESSION['cart'])) {
    $_SESSION['cart'] = [];
}

// Function to update quantities
if (isset($_POST['update'])) {
    foreach ($_POST['quantity'] as $id => $quantity) {
        if (isset($_SESSION['cart'][$id])) {
            if ($quantity <= 0) {
                unset($_SESSION['cart'][$id]);
            } else {
                $_SESSION['cart'][$id]['quantity'] = $quantity;
            }
        }
    }
    header('Location: cart.php');
    exit();
}

// Function to remove items
if (isset($_GET['remove'])) {
    $id = $_GET['remove'];
    if (isset($_SESSION['cart'][$id])) {
        unset($_SESSION['cart'][$id]);
    }
    header('Location: cart.php');
    exit();
}

// Render the cart
?>
<!DOCTYPE html>
<html lang="en">
	<head>
		<meta charset="utf-8">
		<title>Your Cart | Storehouse</title>
		<meta name="author" content="Dominic Cook">
		<meta name="description" content="Storehouse Bindery Official Site">
		<meta name="viewport" content="width=device-width, inital-scale=1">
		<meta name="robots" content"index, follow">
		<link rel="icon" href="https://dominiccook.xyz/favicon.ico">
		<link rel="apple-touch-icon" href="https://dominiccook.xyz/favicon.png">	
        <link rel="stylesheet" type="text/css" href="https://storehousebindery.com/assets/css/style.css"/>
		<script src="https://dominiccook.xyz/assets/js/banner.js"></script>
        <script src="https://code.jquery.com/jquery-3.7.1.min.js"></script>
	</head>
<body>
        <div class="window" id="header">
            <div class="page">
                <ul class="nav nav-pills">
                    <li class="nav-item"><a href="https://storehousebindery.com" class="" aria-current="page">Home</a></li>
                    <li class="nav-item"><a href="#" class="">About</a></li>
                    <li class="nav-item"><a href="#" class="">Collections</a></li>
                    <li class="nav-item"><a href="https://storehousebindery.com/cart.php" class="">Cart</a></li>
                </ul>
            </div>
        </div>
    <h1 class="title">Your Cart</h1>
    <?php if (empty($_SESSION['cart'])): ?>
        <p>Your cart is empty.</p>
    <?php else: ?>
        <form method="post" action="cart.php">
            <table>
                <tr class="cart-header">
                    <th class="cover">PRODUCT</th>
                    <th class="title">Item</th>
                    <th class="price">Price</th>
                    <th class="quantity">Quantity</th>
                    <th class="total">SUBTOTAL</th>
                    <th></th>
                </tr>
                </hr>
                <?php foreach ($_SESSION['cart'] as $id => $item): ?>
                    <tr class="cart-item">
                        <td class="cover"> 
                            <a href="<?php echo htmlspecialchars($item['product_page']); ?>">
                                <img src="<?php echo htmlspecialchars($item['cover_file']); ?>" alt="Book Cover" style="width:120px;height:auto;">
                            </a>
                        </td>
                        <td class="title"><?php echo htmlspecialchars($item['title']); ?></td>
                        <td class="author"><?php echo htmlspecialchars($item['author']); ?></td>
                        <td class="price">$<?php echo number_format($item['price'], 2); ?></td>
                        <td class="number">
                            <div class="quantity">
                                <input type="number" name="quantity[<?php echo $id; ?>]" value="<?php echo $item['quantity']; ?>" min="0" type="submit" name="update">
                            </div>
                        </td>
                        <td class="total">$<?php echo number_format($item['price'] * $item['quantity'], 2); ?></td>
                        <td class="remove">
                            <a href="cart.php?remove=<?php echo $id; ?>">Remove</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </table>
            <br>
            <button id="update" type="submit" name="update">Update Cart</button>
        </form>
        <p>
            <strong>Subtotal: </strong>
            <?php 
                $total = 0;
                foreach ($_SESSION['cart'] as $item) {
                    $total += $item['price'] * $item['quantity'];
                }
                echo number_format($total, 2);
            ?>
        </p>
        <p><a href="checkout.php"><button class="checkout" name="checkout">Proceed to checkout</button></a> <a href="https://storehousebindery.com"><button class="checkout" name="continue-shopping">Continue shopping</button></a></p>
    <?php endif; ?>
                <script>
                jQuery('<div class="quantity-nav"><div class="quantity-button quantity-up">+</div><div class="quantity-button quantity-down">-</div></div>').insertAfter('.quantity input');
                jQuery('.quantity').each(function() {
                    var spinner = jQuery(this),
                        input = spinner.find('input[type="number"]'),
                        btnUp = spinner.find('.quantity-up'),
                        btnDown = spinner.find('.quantity-down'),
                        min = input.attr('min'),
                        max = input.attr('max');

                    btnUp.click(function() {
                        var oldValue = parseFloat(input.val());
                        if (oldValue >= max) {
                            var newVal = oldValue;
            } else {
                var newVal = oldValue + 1;
            }
            spinner.find("input").val(newVal);
            spinner.find("input").trigger("change");
          });

          btnDown.click(function() {
              var oldValue = parseFloat(input.val());
              if (oldValue <= min) {
                  var newVal = oldValue;
            } else {
                var newVal = oldValue - 1;
            }
            spinner.find("input").val(newVal);
            spinner.find("input").trigger("change");
          });

        });
    </script>
</body>
</html>
